=== modified file 'EXTERNALS'
--- EXTERNALS	2010-07-14 15:34:17 +0000
+++ EXTERNALS	2010-08-12 03:30:02 +0000
@@ -10,6 +10,10 @@
 	By "metajack"
 	<http://djangosnippets.org/snippets/797/>
 
+./harvest/common/templatetags/humanize_timediff.py
+	By "supsupmo"
+	<http://djangosnippets.org/snippets/412/>
+
 ./harvest/media/css/reset.css
 	By Eric Meyer
 	<http://meyerweb.com/eric/tools/css/reset/>

=== added file 'harvest/common/templatetags/humanize_timediff.py'
--- harvest/common/templatetags/humanize_timediff.py	1970-01-01 00:00:00 +0000
+++ harvest/common/templatetags/humanize_timediff.py	2010-08-12 03:30:02 +0000
@@ -0,0 +1,51 @@
+#Template filter to provide a string similar to the built in timesince
+#filter, but slightly fuzzier.
+#From <http://djangosnippets.org/snippets/412/> with localization added
+
+from django.utils.translation import ungettext
+from django import template
+
+register = template.Library()
+
+@register.filter
+def humanize_timediff(timestamp = None):
+    """
+    Returns a humanized string representing time difference
+    between now() and the input timestamp.
+    
+    The output rounds up to days, hours, minutes, or seconds.
+    4 days 5 hours returns '4 days'
+    0 days 4 hours 3 minutes returns '4 hours', etc...
+    """
+    import datetime
+    
+    timeDiff = datetime.datetime.now() - timestamp
+    days = timeDiff.days
+    hours = timeDiff.seconds/3600
+    minutes = timeDiff.seconds%3600/60
+    seconds = timeDiff.seconds%3600%60
+    
+    str = ""
+    tStr = ""
+    if days > 0:
+        str = ungettext('%(days)d day', '%(days)d days', days) % {
+            'days' : days
+        }
+        return str
+    elif hours > 0:
+        str = ungettext('%(hours)d hour', '%(hours)d hours', hours) % {
+            'hours' : hours
+        }
+        return str
+    elif minutes > 0:
+        str = ungettext('%(minutes)d minute', '%(minutes)d minutes', minutes) % {
+            'minutes' : minutes
+        }
+        return str
+    elif seconds > 0:
+        str = ungettext('%(seconds)d second', '%(seconds)d seconds', seconds) % {
+            'seconds' : seconds
+        }
+        return str
+    else:
+        return None

=== removed file 'harvest/common/templatetags/list_to_columns.py'
--- harvest/common/templatetags/list_to_columns.py	2009-07-08 11:31:32 +0000
+++ harvest/common/templatetags/list_to_columns.py	1970-01-01 00:00:00 +0000
@@ -1,30 +0,0 @@
-from django import template
-
-register = template.Library()
-
-class SplitListNode(template.Node):
-    def __init__(self, list, cols, new_list):
-        self.list = list
-        self.cols = cols
-        self.new_list = new_list
-
-    def split_seq(self, list, cols=2):
-        start = 0
-        for i in xrange(cols):
-            stop = start + len(list[i::cols])
-            yield list[start:stop]
-            start = stop
-
-    def render(self, context):
-        context[self.new_list] = self.split_seq(context[self.list],
-            int(self.cols))
-        return ''
-
-def list_to_columns(parser, token):
-    bits = token.contents.split()
-    if len(bits) != 5:
-        raise template.TemplateSyntaxError, "list_to_columns list as new_list 2"
-    if bits[2] != 'as':
-        raise template.TemplateSyntaxError, "second argument to the list_to_columns tag must be 'as'"
-    return SplitListNode(bits[1], bits[4], bits[3])
-list_to_columns = register.tag(list_to_columns)

=== modified file 'harvest/media/css/style.css'
--- harvest/media/css/style.css	2010-08-06 03:52:07 +0000
+++ harvest/media/css/style.css	2010-08-12 03:30:02 +0000
@@ -414,14 +414,14 @@
 
 .opportunity-notes {
 	display:block;
-	max-width:30em;
+	width:100%;
+	max-width:35em;
 	border-left:dashed 1px rgb(180,180,180);
 	padding:0px 5px 0px 5px;
 	font-size:12px;
 }
-.opportunity-notes > input.note-input {
+.opportunity-notes > input#new_note {
 	width:100%;
-	margin-bottom:1em;
 	border:none;
 	border-bottom:1px solid rgb(180,180,180);
 	
@@ -431,18 +431,18 @@
 	font:inherit;
 }
 .opportunity-notes > ul {
+	margin:0.5em 0;
 	max-height:10em;
 }
 .opportunity-notes > ul > li {
-	clear:both;
-	margin-bottom:1em;
 	padding-left:10px;
 	text-indent:-10px;
 }
 .opportunity-notes > ul > li > .signature {
-	float:right;
 	margin-left:1em;
+	vertical-align:sub;
 	color:rgb(180,180,180);
+	font-style:italic;
 	font-size:smaller;
 }
 

=== modified file 'harvest/opportunities/forms.py'
--- harvest/opportunities/forms.py	2010-03-08 16:53:44 +0000
+++ harvest/opportunities/forms.py	2010-08-12 03:30:02 +0000
@@ -3,7 +3,9 @@
 from models import Opportunity
 
 class OpportunityForm(forms.ModelForm):
+    new_note = forms.CharField(max_length=250) #from models.Note.text
+    
     class Meta:
         model = Opportunity
-        exclude = ('description', 'url', 'last_updated', 'since', 'sourcepackage', 'opportunitylist', 'valid')
+        fields = ('experience', 'applied', 'reviewed')
 

=== modified file 'harvest/opportunities/models.py'
--- harvest/opportunities/models.py	2010-08-11 23:36:17 +0000
+++ harvest/opportunities/models.py	2010-08-12 03:30:02 +0000
@@ -112,12 +112,12 @@
     opportunity = models.ForeignKey(Opportunity)
     date = models.DateTimeField(auto_now_add=True)
     author = models.ForeignKey(User)
-    text = models.CharField(max_length=500)
+    text = models.CharField(max_length=250)
     
     def __unicode__(self):
         text = self.text
         if len(text) > 40:
-            text = u'%s\u2026' % text[:40]
+            text = text[:40]+u"\u2026"
         return '%s: %s' % (self.author, text)
 
 

=== modified file 'harvest/opportunities/views.py'
--- harvest/opportunities/views.py	2010-08-11 23:36:17 +0000
+++ harvest/opportunities/views.py	2010-08-12 03:30:02 +0000
@@ -13,6 +13,8 @@
 import models
 import forms
 
+from models import Opportunity, Note # for form processing
+
 from filters import HarvestFilters
 from wrappers import PackageWrapper, PackageListWrapper
 
@@ -86,14 +88,22 @@
                 models.log_action(request.user, 
                                   action="changed experience to: %s" % form.cleaned_data["experience"],
                                   opportunity=opportunity)
-            if form.cleaned_data["comment"] != opportunity.comment:
-                if len(form.cleaned_data["comment"]) > 178:
-                    action = "changed comment to: '%s'" % (form.cleaned_data["comment"][:177]+u"…")
-                else:
-                    action = "changed comment to: '%s'" % form.cleaned_data["comment"]
-                models.log_action(request.user, action=action,
-                                  opportunity=opportunity)
             form.save()
+            
+            #add a new note if input by the user
+            if form.cleaned_data["new_note"] != '':
+                note_text = form.cleaned_data["new_note"]
+                
+                note_log_text = note_text
+                if len(note_log_text) > 160:
+                    note_log_text = note_log_text[:160]+u"\u2026"
+                models.log_action(request.user,
+                                  action="added note: '%s'" % note_log_text,
+                                  opportunity=opportunity)
+                
+                note = Note(opportunity=opportunity, author=request.user, text=note_text)
+                note.save()
+            
             return HttpResponseRedirect(request.POST["next"])
         else:
             request.user.message_set.create(message=_('Opportunity details could not be saved.'))

=== modified file 'harvest/templates/opportunities/include/opportunity_details.html'
--- harvest/templates/opportunities/include/opportunity_details.html	2010-08-06 02:53:59 +0000
+++ harvest/templates/opportunities/include/opportunity_details.html	2010-08-12 03:30:02 +0000
@@ -1,3 +1,7 @@
-{% if opportunity.comment %}
-	<span class="opportunity-notes">{{ opportunity.comment }}</span>
-{% endif %}
\ No newline at end of file
+{% ifnotequal opportunity.note_set.count 0 %}
+<div class="opportunity-notes">
+	<ul>
+		{% include "opportunities/include/opportunity_notes_list.html" %}
+	</ul>
+</div>
+{% endifnotequal %}
\ No newline at end of file

=== modified file 'harvest/templates/opportunities/include/opportunity_details_edit.html'
--- harvest/templates/opportunities/include/opportunity_details_edit.html	2010-08-06 03:34:17 +0000
+++ harvest/templates/opportunities/include/opportunity_details_edit.html	2010-08-12 03:30:02 +0000
@@ -2,11 +2,9 @@
 
 <form action="{{ request.path_info }}" method="POST">
 	<div class="opportunity-notes">
-		<input type="text" name="note-input" class="note-input" placeholder="(Make a note here)" />
+		<input type="text" name="new_note" id="new_note" placeholder="(Make a note here)" />
 		<ul>
-			<li>This is the song that never ends… Yes, it goes on and on, my friend. Some people started singing it, not knowing what it was, and they'll keep on singing it forever just because… <span class="signature">some bozo who wants to stress out my css, 3 August 2010</span></li>
-			<li>Note 1 <span class="signature">bob, 3 August 2009</span></li>
-			<li>Another note <span class="signature">dave, 19 July 2008</span></li>
+			{% include "opportunities/include/opportunity_notes_list.html" %}
 		</ul>
 		<div class="bottom"></div>
 	</div>

=== added file 'harvest/templates/opportunities/include/opportunity_notes_list.html'
--- harvest/templates/opportunities/include/opportunity_notes_list.html	1970-01-01 00:00:00 +0000
+++ harvest/templates/opportunities/include/opportunity_notes_list.html	2010-08-12 03:30:02 +0000
@@ -0,0 +1,9 @@
+{% load i18n %}
+{% load humanize_timediff %}
+
+{% for note in opportunity.note_set.all|dictsortreversed:"date" %}
+<li>
+	{{ note.text }}
+	<span class="signature">{% blocktrans with note.date|humanize_timediff as timesince and note.author as author %}{{author}}, {{timesince}} ago{% endblocktrans %}</span>
+</li>
+{% endfor %}

